@@ -5,34 +5,6 @@ from ROTools.Helpers.Attr import setattr_ex, hasattr_ex, getattr_ex, delattr_ex
 from ROTools.Helpers.DumpBase import DumpBase
 
 
-def _gen_fields_list(obj, current_path=None):
-    if not isinstance(obj, DictObj):
-        return [(current_path, obj)]
-    result = []
-    for key, value in obj.items():
-        next_path = ".".join([a for a in (current_path, key) if a is not None])
-
-        if isinstance(value, DictObj):
-            result.extend(_gen_fields_list(value, current_path=next_path))
-        else:
-            result.append((next_path, value))
-    return result
-
-def _convert_to_dict(obj):
-    if isinstance(obj, DictObj):
-        return obj.to_dict()
-
-    if isinstance(obj, datetime):
-        return obj.isoformat()
-
-    if isinstance(obj, date):
-        return obj.isoformat()
-
-    if isinstance(obj, list) or isinstance(obj, tuple):
-        return [_convert_to_dict(a) for a in obj]
-
-    return obj
-
 
 class DictObj(DumpBase):
     def __init__(self, d=None):
@@ -56,12 +28,22 @@ class DictObj(DumpBase):
                 continue
             setattr(self, a, DictObj(b) if isinstance(b, dict) else b)
 
-    def get(self, path, default=None):
+    def get(self, path, default=None, throw=False):
+        if throw and not self.has(path):
+            raise Exception("Path not found: " + path)
         return getattr_ex(self, path, default)
 
     def set(self, path, value):
         setattr_ex(self, path, value, parent_class=DictObj)
 
+    def copy(self, obj, path, default=None, throw=False):
+        if isinstance(path, list):
+            for item in path:
+                self.copy(obj, item, default=default, throw=throw)
+            return
+        value = obj.get(path, default=default, throw=throw)
+        self.set(path, value)
+
     def rem(self, path):
         return delattr_ex(self, path)
 
@@ -69,7 +51,7 @@ class DictObj(DumpBase):
         return hasattr_ex(self, path)
 
     def convert(self, path, cb):
-        if not hasattr(self, path):
+        if not self.has(path):
             return
         self.set(path, cb(self.get(path)))
 
@@ -104,3 +86,32 @@ class DictObj(DumpBase):
     def clone(self):
         import copy
         return copy.deepcopy(self)
+
+
+def _gen_fields_list(obj, current_path=None):
+    if not isinstance(obj, DictObj):
+        return [(current_path, obj)]
+    result = []
+    for key, value in obj.items():
+        next_path = ".".join([a for a in (current_path, key) if a is not None])
+
+        if isinstance(value, DictObj):
+            result.extend(_gen_fields_list(value, current_path=next_path))
+        else:
+            result.append((next_path, value))
+    return result
+
+def _convert_to_dict(obj):
+    if isinstance(obj, DictObj):
+        return obj.to_dict()
+
+    if isinstance(obj, datetime):
+        return obj.isoformat()
+
+    if isinstance(obj, date):
+        return obj.isoformat()
+
+    if isinstance(obj, list) or isinstance(obj, tuple):
+        return [_convert_to_dict(a) for a in obj]
+
+    return obj
\ No newline at end of file
