@@ -1,7 +1,7 @@
 class RedisSingletonLock:
-    def __init__(self, redis, lock_timeout=30):
+    def __init__(self, redis, lock_key=None, lock_timeout=30):
         self.redis = redis
-        self.lock_key = 'app_lock'
+        self.lock_key = lock_key
         self.lock_timeout = lock_timeout
         self.lock_acquired = False
 
